---
title: Available Components
---

This is a collection of components for Kodexa.

You can learn more about what components are in Kodexa (here)[https://kodexa-ai.github.io/platform/overview/components].

{% for component_type in component %}
## {{component_type}}

{% for slug in component['actions'] %}
* {{slug}}
{% endfor %}
{% endfor %}