
    {%- for child_taxon in taxon.children -%}
    {%- if child_taxon.group -%}
    {{  child_taxon.name }} ||--o{ {{ taxon.name }} : contains
    {% with taxon=child_taxon %}
    {%- include 'taxon.jinja2' -%}
    {%- endwith -%}
    {%- endif -%}
    {%- endfor -%}
    {{ taxon.name }} {
    {%- for taxon in taxon.children -%}
        {% if not taxon.group %}
        {{ taxon.taxon_type if taxon.taxon_type else 'string' }} {{  taxon.name }}
        {%- endif -%}
    {% endfor %}
    }
