# {{ component.name }}
{% if component.image_url %}
<img src="{{ component.image_url }}" style="float: right; margin-right: 10px; margin-top: -20px; padding: 25px; width: 200px; height: 200px" />
{% endif %}
<div style="size: 0.6em; font-weight: bold">{{ component.slug }}</div>
{% if component.lifecycle %}
Lifecycle: {{ component.lifecycle }}
{% endif %}

{{ component.description }}
{% if component.overview_markdown %}
{{ component.overview_markdown }}
{% endif %}
You can list a component in the marketplace, and define if you want it to be a template.

{% if component.public_access %}
✅ Available in Marketplace
{% else %}
❌ Not available in Marketplace
{% endif %}

{% if component.template %}
✅ Can be used as a template to create a new component
{% else %}
❌ Can not be used as a template
{% endif %}