{%- if children and children is iterable  %}
{%- for child_taxon in children -%}

<style>
.{{ child_taxon.name }} {
  color: {{ child_taxon.color }};
}
</style>
### :material-tag:{ .{{ child_taxon.name }} }  {{ child_taxon.label }}

{% if child_taxon.description %}
{{ child_taxon.description }}
{% endif %}

{% if child_taxon.options and child_taxon.options|length > 0 %}
*Options*

This taxon has the following options:
{% with options=child_taxon.options %}
{% include 'options.jinja2' %}
{% endwith %}
{% endif %}

{%- if child_taxon.children and child_taxon.children is iterable -%}
{% with children=child_taxon.children %}
{% include 'processing-taxon.jinja2' %}
{% endwith %}
{%- endif %}
{% endfor %}
{%- endif %}
